@@ -6,7 +6,7 @@ from colorama import Fore, Style
 from sumatra.config import CONFIG
 from sumatra.auth import CognitoAuth
 from sumatra.client import Client
-from sumatra.admin import AdminClient
+
 
 logger = logging.getLogger("sumatra.cli")
 
@@ -281,30 +281,33 @@ def tenant(args):
 
 
 def admin_list_tenants(args):
-    tenants = AdminClient(args.aws_profile).list_tenants()
+    tenants = Client().list_tenants()
     print("\n".join(tenants))
 
 
 def admin_current_tenant(args):
-    print(AdminClient(args.aws_profile).current_tenant(args.user))
+    user = Client().get_user(args.user)
+    print(user["tenant"] + "\t" + user["role"])
 
 
 def admin_assign_tenant(args):
-    AdminClient(args.aws_profile).assign_tenant(args.user, args.tenant)
-    print(f"Successfully assigned '{args.user}' to '{args.tenant}'.")
+    Client().set_tenant(args.user, args.tenant)
+    Client().set_role(args.user, args.role)
+
+    print(f"Successfully assigned '{args.user}' to '{args.tenant}' with '{args.role}' role.")
 
 
 def admin_list_users(args):
-    users = AdminClient(args.aws_profile).list_users()
+    users = Client().list_users()
     print("\n".join(users))
 
 
 def admin_show_keys(args):
-    print(AdminClient(args.aws_profile).get_keys())
+    print(Client().get_keys())
 
 
 def admin_show_key_usage(args):
-    print(AdminClient(args.aws_profile).get_key_usage())
+    print(Client().get_key_usage())
 
 
 ADMIN_COMMANDS = [
@@ -602,6 +605,7 @@ def main():
                         p.add_argument("user", help="cognito login name of user")
                     if subcmd["name"] == "assign-tenant":
                         p.add_argument("tenant", help="tenant name")
+                        p.add_argument("role", help="role name (reader, writer, publisher)")
 
     args = parser.parse_args()
 
