@@ -83,6 +83,21 @@ def _splitext(path: str):
     return os.path.basename(path), fullext
 
 
+def _humanize_status(status: str):
+    """
+    Translate server-side status to human-readable, standardized identifier
+    """
+    standardize = {
+        "New": "Processing",
+        "Running": "Processing",
+        "Offline": "Processing",
+        "Online": "Ready",
+    }
+    if status in standardize:
+        return standardize[status]
+    return status.title()
+
+
 class Client:
     """
     Client to connect to Sumatra GraphQL API
@@ -1316,6 +1331,52 @@ class Client:
 
         return Materialization(self, ret["data"]["materialize"]["id"])
 
+    def replay(
+        self,
+        features: List[str],
+        start_ts: Union[pd.Timestamp, str],
+        end_ts: Union[pd.Timestamp, str],
+        extra_timelines: Optional[List[str]] = None,
+        branch: Optional[str] = None,
+    ) -> Materialization:
+        """
+        Recompute historical feature values from LIVE event log on given topology branch.
+
+        This is the primary function of the SDK.
+
+        Arguments:
+            features: List of features to materialize, e.g. `['login.email', 'purchase.*']`
+            start_ts: Earliest event timestamp to materialize (local client timezone).
+            end_ts: Latest event timestamp to materialize (local client timezone).
+            extra_timelines: Names of supplemental timelines.
+            branch: Specify a source branch other than the client default.
+
+        Returns:
+            Handle to Materialization job
+        """
+
+        if isinstance(start_ts, pd.Timestamp):
+            start_ts = str(start_ts)
+        start = pendulum.parse(start_ts, tz=CONFIG.timezone).astimezone(
+            pendulum.timezone("UTC")
+        )
+        start = int(start.timestamp())
+
+        if isinstance(end_ts, pd.Timestamp):
+            end_ts = str(end_ts)
+        end = pendulum.parse(end_ts, tz=CONFIG.timezone).astimezone(
+            pendulum.timezone("UTC")
+        )
+        end = int(end.timestamp())
+
+        live_timeline = f"live_{start}_{end}"
+        self.create_timeline_from_log(live_timeline, start_ts, end_ts)
+
+        timelines = (extra_timelines or []) + [live_timeline]
+        return self.distributed_materialize_many(
+            timelines, features, start_ts, end_ts, branch
+        )
+
     def distributed_materialize_many(
         self,
         timelines: List[str],
@@ -1327,8 +1388,6 @@ class Client:
         """
         Enrich collection of timelines using topology at branch. Timelines are merged based on timestamp.
 
-        This is the primary function of the SDK.
-
         Arguments:
             timelines: Timeline names.
             branch: Specify a source branch other than the client default.
@@ -1671,7 +1730,7 @@ class Client:
             row = {
                 "version": version["version"],
                 "row_count": version["rowCount"],
-                "status": version["status"],
+                "status": _humanize_status(version["status"]),
                 "create_ts": version["createdAt"],
                 "created_by": version["creator"],
             }
@@ -1914,6 +1973,198 @@ class Client:
         if "errors" in ret:
             raise RuntimeError(ret["errors"][0]["message"])
 
+    def list_users(self) -> None:
+        """
+        List users.
+        """
+        query = """
+            query ListUsers {
+                users {
+                    nodes {
+                        username
+                    }
+                }
+            }
+        """
+
+        ret = self._gql_client.execute(query=query)
+
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+        return [user["username"] for user in ret["data"]["users"]["nodes"]]
+
+    def get_user(self, username: str) -> Dict[str, str]:
+        """
+        Get User.
+        """
+        query = """
+            query User($username: String!) {
+                user(username: $username) {
+                    username
+                    email
+                    role
+                    tenant
+                    admin
+                    status
+                }
+            }
+        """
+
+        ret = self._gql_client.execute(
+            query=query,
+            variables={
+                "username": username,
+            },
+        )
+
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+        return ret["data"]["user"]
+
+    def list_tenants(self) -> None:
+        """
+        List tenants.
+        """
+        query = """
+                query ListTenants {
+                    tenants {
+                        nodes {
+                            key
+                        }
+                    }
+                }
+            """
+
+        ret = self._gql_client.execute(query=query)
+
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+        return [tenant["key"] for tenant in ret["data"]["tenants"]["nodes"]]
+
+    def set_tenant(self, username: Str, tenant: Str):
+        """
+        Set tenant for user
+        """
+        query = """
+            mutation SetTenant($username: String!, $tenant: String!) {
+                 setUserTenant(username: $username, tenant: $tenant) {
+                    tenant
+                    username
+                  }
+            }
+        """
+
+        ret = self._gql_client.execute(
+            query=query,
+            variables={
+                "username": username,
+                "tenant": tenant,
+            },
+        )
+
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+    def set_role(self, username: Str, role: Str):
+        """
+        Set role for user
+        """
+        query = """
+            mutation SetRole($username: String!, $role: String!) {
+                 setUserRole(username: $username, role: $role) {
+                    role
+                    username
+                  }
+            }
+        """
+
+        ret = self._gql_client.execute(
+            query=query,
+            variables={
+                "username": username,
+                "role": role,
+            },
+        )
+
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+    def get_keys(self) -> pd.DataFrame:
+        """
+        Get API Keys for tenants
+        """
+        query = """
+            query ApiKeys {
+                tenants {
+                    nodes {
+                        key
+                        apiKey
+                        sdkKey
+                    }
+                }
+            }
+        """
+
+        ret = self._gql_client.execute(query=query)
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+        rows = []
+        for tenant in ret["data"]["tenants"]["nodes"]:
+            rows.append((tenant["key"], "api", tenant["apiKey"]))
+            rows.append((tenant["key"], "sdk", tenant["sdkKey"]))
+
+        return (
+            pd.DataFrame(rows, columns=("Tenant", "Type", "Key"))
+            .set_index(["Tenant", "Type"])
+            .sort_index()
+        )
+
+    def get_key_usage(self, start_date=None, end_date=None) -> pd.DataFrame:
+        """
+        Get API Key usage for tenants
+        """
+        query = """
+            query ApiKeyUsage($startDate: DateTime!, $endDate: DateTime!) {
+                apiKeyUsage(startDate: $startDate, endDate: $endDate) {
+                    tenant
+                    apiType
+                    dailyUsage
+                }
+            }
+        """
+
+        end_date = end_date or pendulum.today()
+        start_date = start_date or end_date.subtract(days=6)
+
+        ret = self._gql_client.execute(
+            query=query,
+            variables={
+                "startDate": start_date.to_iso8601_string(),
+                "endDate": end_date.to_iso8601_string(),
+            },
+        )
+
+        if "errors" in ret:
+            raise RuntimeError(ret["errors"][0]["message"])
+
+        days = [d.to_date_string() for d in end_date - start_date]
+        rows = []
+        for usage in ret["data"]["apiKeyUsage"]:
+            dailyUsage = usage["dailyUsage"]
+            if len(dailyUsage) == 0:
+                dailyUsage = [0 for _ in days]
+            rows.append([usage["tenant"], usage["apiType"]] + dailyUsage)
+
+        return (
+            pd.DataFrame(rows, columns=["Tenant", "Type"] + days)
+            .set_index(["Tenant", "Type"])
+            .sort_index()
+        )
+
 
 class TableVersion:
     """
@@ -1949,7 +2200,7 @@ class TableVersion:
         Current status of the job. One of {'New', 'Offline', 'Online', 'Error'}
         """
         self._tv = self._get_table_version()
-        return self._tv["status"]
+        return _humanize_status(self._tv["status"])
 
     @property
     def error(self) -> Optional[str]:
@@ -1968,7 +2219,7 @@ class TableVersion:
             Table version upload status
         """
 
-        expected_status = "Online"  # in the future, Offline may be a final state
+        expected_status = "Ready"
         while self.status not in [expected_status, "Error"]:
             time.sleep(0.5)
 
