@@ -70,16 +70,17 @@ class Config:
     def _get_or_stack(self, key: str) -> str:
         val = self._get(key)
         if val is None:
-            self._update_from_stack(self._fetch_stack())
+            self.update_from_stack()
             val = self._get(key)
         if val is None:
             raise KeyError
         return val
 
-    def _set(self, key: str, val: str) -> None:
+    def _set(self, key: str, val: str) -> str:
         if self.instance not in self._config:
             self._config.add_section(self.instance)
         self._config[self.instance][key] = val
+        return val
 
     def _fetch_stack(self) -> Dict[str, str]:
         stack_config_url = urljoin(self.instance_url, "stack.json")
@@ -92,7 +93,8 @@ class Config:
         except:
             raise Exception("error fetching stack config from: " + stack_config_url)
 
-    def _update_from_stack(self, stack: Dict[str, str]) -> None:
+    def update_from_stack(self, stack: Optional[Dict[str, str]] = None) -> None:
+        stack = stack or self._fetch_stack()
         self._set("user_pool_client_id", stack["user_pool_client_id"])
         self._set("user_pool_id", stack["user_pool_id"])
         user_pool_domain = stack["user_pool_domain"]
@@ -153,11 +155,11 @@ class Config:
         return self._get("jwt_token")
 
     @property
-    def jwt_tokens_path(self) -> Optional[str]:
+    def jwt_tokens_path(self) -> str:
         return self._get("jwt_tokens_path") or os.path.join(_CONFIG_PATH, ".jwt-tokens")
 
     @property
-    def default_branch(self) -> Optional[str]:
+    def default_branch(self) -> str:
         return self._get("default_branch") or "dev_" + getpass.getuser()
 
     @default_branch.setter
@@ -170,7 +172,7 @@ class Config:
         return self._get("timezone") or pendulum.now().timezone_name
 
     @property
-    def scowl_dir(self) -> Optional[str]:
+    def scowl_dir(self) -> str:
         return self._get("scowl_dir") or "."
 
     @property
@@ -190,22 +192,20 @@ class Config:
         auth_url = self._get("cognito_auth_url")
         if auth_url:
             return auth_url
-        self._set(
+        return self._set(
             "cognito_auth_url",
             f"https://{self.user_pool_domain}.auth.us-east-1.amazoncognito.com/login",
         )
-        return self._get("cognito_auth_url")
 
     @property
     def cognito_token_url(self) -> str:
         token_url = self._get("cognito_token_url")
         if token_url:
             return token_url
-        self._set(
+        return self._set(
             "cognito_token_url",
             f"https://{self.user_pool_domain}.auth.us-east-1.amazoncognito.com/oauth2/token",
         )
-        return self._get("cognito_token_url")
 
     @property
     def api_endpoint(self) -> str:
